package com.livelike.flickersearchlibrary

import com.livelike.flickersearchlibrary.api.model.Photo
import com.livelike.flickersearchlibrary.di.Dependencies
import com.livelike.flickersearchlibrary.service.FlickrService
import org.koin.java.KoinJavaComponent.inject

/**
 * Defines Flickr service features.
 */
object Flickr {

    init {
        Dependencies.init()
    }

    private val flickrService: FlickrService by inject(FlickrService::class.java)

    private const val DEFAULT_NUMBER_OF_PHOTOS_PER_PAGE = 20

    /**
     * Provides search results for given search term. [numOfPhotos] will be returned on given [page].
     * By default 20 photos will be returned on the first page.
     * If no search query is provided, empty results will be returned.
     *
     * @param searchQuery [String] the search term for which photo results should be returned.
     * @param numOfPhotos [Int] number of photos to return.
     * @param page [Int] the page where the photos should be contained.
     * @return [List] of [Photo]s matching the given search term, or empty results if no term is provided.
     */
    suspend fun search(
        searchQuery: String?, numOfPhotos: Int = DEFAULT_NUMBER_OF_PHOTOS_PER_PAGE,
        page: Int = 1
    ) = flickrService.search(searchQuery, numOfPhotos, page)

    /**
     * Retrieves [numOfPhotos] recently published photos on Flickr on the given [page].
     * By default, 20 photos are returned, and the default page is the first page.
     *
     * @param numOfPhotos [Int] number of photos to return.
     * @param page [Int] the page where photos should be contained.
     * @return [List] of recently published photos on Flickr.
     */
    suspend fun getRecentPhotos(
        numOfPhotos: Int = DEFAULT_NUMBER_OF_PHOTOS_PER_PAGE,
        page: Int = 1
    ) = flickrService.getRecentPhotos(numOfPhotos, page)

}